import { ensureEnum, brushToString, stringToBrush, ensureBool, initializePropertiesFromCss, NamePatcher, toSpinal, enumToString, getAllPropertyNames, fromSpinal } from "igniteui-webcomponents-core";
import { FontInfo } from "igniteui-webcomponents-core";
import { WebComponentRenderer } from "igniteui-webcomponents-core";
import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { SyncableObservableCollection$1 } from "igniteui-webcomponents-core";
import { TypeRegistrar } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
import { CheckboxList } from './CheckboxList';
import { IgcCheckedChangedEventArgs } from "./igc-checked-changed-event-args";
import { IgcSelectAllCheckboxChangedEventArgs } from "./igc-select-all-checkbox-changed-event-args";
import { PrimaryKeyValue } from "./PrimaryKeyValue";
import { IgcGridSelectedKeysCollection } from "./igc-grid-selected-keys-collection";
import { GridSelectedKeysCollection as GridSelectedKeysCollection_internal } from "./GridSelectedKeysCollection";
import { CheckboxListIndexType_$type } from "./CheckboxListIndexType";
import { InputGroupDisplayType_$type } from "igniteui-webcomponents-inputs";
import { BaseControlTheme_$type } from "igniteui-webcomponents-core";
import { ControlDisplayDensity_$type } from "igniteui-webcomponents-core";
import { ScrollbarStyle_$type } from "igniteui-webcomponents-core";
import { IgcHTMLElement } from "igniteui-webcomponents-core";
export let IgcCheckboxListComponent = /*@__PURE__*/ (() => {
    class IgcCheckboxListComponent extends IgcHTMLElement {
        set height(value) {
            this._height = value;
            this.style.height = value;
            this.i.notifySizeChanged();
        }
        get height() {
            return this._height;
        }
        set width(value) {
            this._width = value;
            this.style.width = value;
            this.i.notifySizeChanged();
        }
        get width() {
            return this._width;
        }
        set dataSource(value) {
            this._dataSource = value;
            if (this._checkboxList != null) {
                this._checkboxList.itemsSource = this._dataSource;
            }
        }
        get dataSource() {
            return this._dataSource;
        }
        constructor() {
            super();
            this._dataSource = null;
            this._disconnected = false;
            this._settingAttributes = false;
            this._attached = false;
            this._queuedSetAttributes = [];
            this._updatingFromAttribute = false;
            this._keys = null;
            this.__p = null;
            this._hasUserValues = new Set();
            this._stylingContainer = null;
            this._stylingParent = null;
            this._inStyling = false;
            this._checkedChanged = null;
            this._checkedChanged_wrapped = null;
            this._selectAllCheckboxChanged = null;
            this._selectAllCheckboxChanged_wrapped = null;
            if (this._styling) {
                NamePatcher.ensureStylablePatched(Object.getPrototypeOf(this));
            }
            this._renderer = new WebComponentRenderer(this, document, true, null);
            this._implementation = this.createImplementation();
            this._container = this._renderer.createElement("div");
            this._renderer.updateRoot(this._container);
            this._container.setStyleProperty("display", "block");
            this._container.setStyleProperty("width", "100%");
            this._container.setStyleProperty("height", "100%");
            var checkboxList = this.i;
            this._checkboxList = checkboxList;
            this._renderer.addSizeWatcher(() => {
                this._checkboxList.notifySizeChanged();
            });
        }
        // supports angular themes or custom properties set in CSS
        updateStyle() {
            this._styling(this, this);
        }
        destroy() {
            this._checkboxList.destroy();
        }
        createImplementation() {
            return new CheckboxList();
        }
        disconnectedCallback() {
            this._disconnected = true;
        }
        connectedCallback() {
            if (this._disconnected) {
                this._disconnected = false;
                return;
            }
            this.classList.add("ig-checkbox-list");
            this.classList.add("igc-checkbox-list");
            var rootWrapper = this._renderer.rootWrapper;
            var rootElement = rootWrapper.getNativeElement();
            this.appendChild(rootElement);
            this._attached = true;
            this.style.display = "block";
            this.style.height = this._height;
            this.style.width = this._width;
            var filterContainer = this._renderer.createElement("div");
            this._container.append(filterContainer);
            var filterHr = this._renderer.createElement("hr");
            this._container.append(filterHr);
            filterHr.setStyleProperty("margin", "3px 0px");
            filterHr.setStyleProperty("border-top", "1px solid #dde2eb");
            filterHr.setStyleProperty("border-left", "0px");
            filterHr.setStyleProperty("border-right", "0px");
            filterHr.setStyleProperty("border-bottom", "0px");
            this.i.provideHrElement(filterHr);
            /*var filterInput = this._renderer.createElement("input");
            filterInput.getNativeElement().type = "text";
            filterContainer.append(filterInput);*/
            var selectAllSection = this._renderer.createElement("div");
            this._container.append(selectAllSection);
            var grid = this._renderer.createElement("igc-data-grid");
            grid.getNativeElement().headerHeight = 0;
            this._container.append(grid);
            this._checkboxList.provideContainer(this._renderer, grid.getNativeElement().i, selectAllSection);
            this._checkboxList.notifySizeChanged();
            this._flushQueuedAttributes();
            // supports themes or custom properties set in CSS 
            this._styling(this, this);
            this.afterContentInit();
        }
        afterContentInit() {
            this.i.notifySizeChanged();
        }
        /**
         * @hidden
         */
        get i() {
            return this._implementation;
        } /**
                                     * @hidden
                                     */
        static _createFromInternal(internal) {
            if (!internal) {
                return null;
            }
            if (!internal.$type) {
                return null;
            }
            let name = internal.$type.name;
            let externalName = "Igc" + name + "Component";
            if (!TypeRegistrar.isRegistered(externalName)) {
                return null;
            }
            return TypeRegistrar.create(externalName);
        }
        _enqueueSetAttribute(attrName, attrValue) {
            this._queuedSetAttributes.push({ attrName: attrName, attrValue: attrValue });
        }
        _flushQueuedAttributes() {
            this._settingAttributes = true;
            for (let i = 0; i < this._queuedSetAttributes.length; i++) {
                this.setAttribute(this._queuedSetAttributes[i].attrName, this._queuedSetAttributes[i].attrValue);
            }
            this._settingAttributes = false;
            this._queuedSetAttributes.length = 0;
        }
        _a(attrName, attrValue) {
            if (this._updatingFromAttribute) {
                return;
            }
            if (attrValue) {
                attrValue = attrValue.toString();
            }
            this._settingAttributes = true;
            attrName = toSpinal(attrName);
            if (this._attached) {
                this.setAttribute(attrName, attrValue);
            }
            else {
                this._enqueueSetAttribute(attrName, attrValue);
            }
            this._settingAttributes = false;
        }
        static get observedAttributes() {
            if (IgcCheckboxListComponent._observedAttributesIgcCheckboxListComponent == null) {
                let names = getAllPropertyNames(IgcCheckboxListComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcCheckboxListComponent._observedAttributesIgcCheckboxListComponent = names;
            }
            return IgcCheckboxListComponent._observedAttributesIgcCheckboxListComponent;
        }
        attributeChangedCallback(name, oldValue, newValue) {
            if (this._settingAttributes) {
                return;
            }
            let setName = fromSpinal(name);
            this._updatingFromAttribute = true;
            this[setName] = newValue;
            this._updatingFromAttribute = false;
        }
        static register() {
            if (!IgcCheckboxListComponent._isElementRegistered) {
                IgcCheckboxListComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcCheckboxListComponent.htmlTagName, IgcCheckboxListComponent);
            }
        }
        /**
         * Gets the collection responsible for selection in the CheckboxList. Selection is determined by two factors:
         * whether everything is selected or deselected and the values present in this collection. If everything is
         * selected then any items in this collection will be deselected. If everything is deselected then any items in
         * this collection will be selected. The CheckboxList defaults all items as deselected. This state can change
         * when you use the SelectAll and DeselectAll methods.
        */
        get keys() {
            if (this._keys === null) {
                let coll = new IgcGridSelectedKeysCollection();
                let innerColl = this.i.g;
                if (!innerColl) {
                    innerColl = new GridSelectedKeysCollection_internal();
                }
                this._keys = coll._fromInner(innerColl);
            }
            return this._keys;
        }
        set keys(v) {
            if (this._keys !== null) {
                this._keys._setSyncTarget(null);
                this._keys = null;
            }
            let coll = new IgcGridSelectedKeysCollection();
            this._keys = coll._fromOuter(v);
            let syncColl = new SyncableObservableCollection$1(PrimaryKeyValue.$type);
            let innerColl = this.i.g;
            if (!innerColl) {
                innerColl = new GridSelectedKeysCollection_internal();
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._keys._setSyncTarget(syncColl);
        }
        /**
         * Gets or sets the primary key to use for the CheckboxList.
        */
        get primaryKey() {
            return this.i.b;
        }
        set primaryKey(v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                const re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.b = v;
        }
        /**
         * Gets or Sets the property name that contains the values.
        */
        get dataMemberPath() {
            return this.i.bc;
        }
        set dataMemberPath(v) {
            this.i.bc = v;
        }
        /**
         * Gets or Sets the property name that contains the values.
        */
        get selectedMemberPath() {
            return this.i.b0;
        }
        set selectedMemberPath(v) {
            this.i.b0 = v;
        }
        /**
         * Gets or Sets the property name that contains the values.
        */
        get filterPlaceholderText() {
            return this.i.bg;
        }
        set filterPlaceholderText(v) {
            this.i.bg = v;
        }
        /**
         * Gets or Sets the property name that contains the values.
        */
        get searchInputType() {
            return this.i.t;
        }
        set searchInputType(v) {
            this.i.t = ensureEnum(InputGroupDisplayType_$type, v);
            this._a("searchInputType", enumToString(InputGroupDisplayType_$type, this.i.t));
        }
        /**
         * Gets or Sets the property name that contains the values.
        */
        get rowHeight() {
            return this.i.ax;
        }
        set rowHeight(v) {
            this.i.ax = +v;
            this._a("rowHeight", this.i.ax);
        }
        get actualRowHeight() {
            return this.i.av;
        }
        /**
         * Gets or Sets the property name that contains the values.
        */
        get cellTextStyle() {
            if (this.i.ae == null) {
                return null;
            }
            return this.i.ae.fontString;
        }
        set cellTextStyle(v) {
            let fi = new FontInfo();
            fi.fontString = v;
            this.i.ae = fi;
            this._a("cellTextStyle", this.i.ae != null ? this.i.ae.fontString : "");
        }
        /**
         * Gets or Sets the property name that contains the values.
        */
        get indexType() {
            return this.i.l;
        }
        set indexType(v) {
            this.i.l = ensureEnum(CheckboxListIndexType_$type, v);
            this._a("indexType", enumToString(CheckboxListIndexType_$type, this.i.l));
        }
        /**
         * Gets or Sets the property name that contains the values.
        */
        get baseTheme() {
            return this.i.y;
        }
        set baseTheme(v) {
            this.i.y = ensureEnum(BaseControlTheme_$type, v);
            this._a("baseTheme", enumToString(BaseControlTheme_$type, this.i.y));
        }
        /**
         * Gets or Sets the property name that contains the values.
        */
        get density() {
            return this.i.aa;
        }
        set density(v) {
            this.i.aa = ensureEnum(ControlDisplayDensity_$type, v);
            this._a("density", enumToString(ControlDisplayDensity_$type, this.i.aa));
        }
        /**
         * Gets or sets the search icon color.
        */
        get searchIconColor() {
            return brushToString(this.i.du);
        }
        set searchIconColor(v) {
            this.i.du = stringToBrush(v);
            this._a("searchIconColor", brushToString(this.i.du));
        }
        /**
         * Gets or sets the search background color.
        */
        get searchBackgroundColor() {
            return brushToString(this.i.ds);
        }
        set searchBackgroundColor(v) {
            this.i.ds = stringToBrush(v);
            this._a("searchBackgroundColor", brushToString(this.i.ds));
        }
        /**
         * Gets or sets the search text color.
        */
        get searchTextColor() {
            return brushToString(this.i.dv);
        }
        set searchTextColor(v) {
            this.i.dv = stringToBrush(v);
            this._a("searchTextColor", brushToString(this.i.dv));
        }
        /**
         * Gets or sets the search border color.
        */
        get searchBorderColor() {
            return brushToString(this.i.dt);
        }
        set searchBorderColor(v) {
            this.i.dt = stringToBrush(v);
            this._a("searchBorderColor", brushToString(this.i.dt));
        }
        /**
         * Gets or sets the text style.
        */
        get searchTextStyle() {
            if (this.i.af == null) {
                return null;
            }
            return this.i.af.fontString;
        }
        set searchTextStyle(v) {
            let fi = new FontInfo();
            fi.fontString = v;
            this.i.af = fi;
            this._a("searchTextStyle", this.i.af != null ? this.i.af.fontString : "");
        }
        /**
         * Gets or sets the checkbox tick color.
        */
        get checkboxTickColor() {
            return brushToString(this.i.dl);
        }
        set checkboxTickColor(v) {
            this.i.dl = stringToBrush(v);
            this._a("checkboxTickColor", brushToString(this.i.dl));
        }
        /**
         * Gets or sets the checkbox background color when checked.
        */
        get checkboxCheckedBackgroundColor() {
            return brushToString(this.i.dj);
        }
        set checkboxCheckedBackgroundColor(v) {
            this.i.dj = stringToBrush(v);
            this._a("checkboxCheckedBackgroundColor", brushToString(this.i.dj));
        }
        /**
         * Gets or sets the checkbox background color when unchecked.
        */
        get checkboxUncheckedBackgroundColor() {
            return brushToString(this.i.dm);
        }
        set checkboxUncheckedBackgroundColor(v) {
            this.i.dm = stringToBrush(v);
            this._a("checkboxUncheckedBackgroundColor", brushToString(this.i.dm));
        }
        /**
         * Gets or sets the checkbox border color when checked.
        */
        get checkboxCheckedBorderColor() {
            return brushToString(this.i.dk);
        }
        set checkboxCheckedBorderColor(v) {
            this.i.dk = stringToBrush(v);
            this._a("checkboxCheckedBorderColor", brushToString(this.i.dk));
        }
        /**
         * Gets or sets the checkbox border color when unchecked.
        */
        get checkboxUncheckedBorderColor() {
            return brushToString(this.i.dn);
        }
        set checkboxUncheckedBorderColor(v) {
            this.i.dn = stringToBrush(v);
            this._a("checkboxUncheckedBorderColor", brushToString(this.i.dn));
        }
        /**
         * Gets or sets the style of scrollbar.
        */
        get scrollbarStyle() {
            return this.i.w;
        }
        set scrollbarStyle(v) {
            this.i.w = ensureEnum(ScrollbarStyle_$type, v);
            this._a("scrollbarStyle", enumToString(ScrollbarStyle_$type, this.i.w));
        }
        /**
         * Gets or sets the scrollbar background color.
        */
        get scrollbarBackground() {
            return brushToString(this.i.dr);
        }
        set scrollbarBackground(v) {
            this.i.dr = stringToBrush(v);
            this._a("scrollbarBackground", brushToString(this.i.dr));
        }
        /**
         * Gets / sets the caption of the "Select All" checkbox.
        */
        get selectAllCaption() {
            return this.i.bx;
        }
        set selectAllCaption(v) {
            this.i.bx = v;
        }
        /**
         * Gets or sets the color to use for the "Select All" label.
        */
        get selectAllCaptionTextColor() {
            return brushToString(this.i.dw);
        }
        set selectAllCaptionTextColor(v) {
            this.i.dw = stringToBrush(v);
            this._a("selectAllCaptionTextColor", brushToString(this.i.dw));
        }
        /**
         * Gets or sets the color to use for the actual header selectAllCaption text.
        */
        get actualSelectAllCaptionTextColor() {
            return brushToString(this.i.dh);
        }
        set actualSelectAllCaptionTextColor(v) {
            this.i.dh = stringToBrush(v);
            this._a("actualSelectAllCaptionTextColor", brushToString(this.i.dh));
        }
        /**
         * Gets / sets whether the "Select all" checkbox is visible.
        */
        get showSelectAll() {
            return this.i.as;
        }
        set showSelectAll(v) {
            this.i.as = ensureBool(v);
            this._a("showSelectAll", this.i.as);
        }
        /**
         * Gets or sets the color to use for the background of the component.
        */
        get backgroundColor() {
            return brushToString(this.i.di);
        }
        set backgroundColor(v) {
            this.i.di = stringToBrush(v);
            this._a("backgroundColor", brushToString(this.i.di));
        }
        /**
         * Gets or sets the color to use for the text of the component.
        */
        get textColor() {
            return brushToString(this.i.dy);
        }
        set textColor(v) {
            this.i.dy = stringToBrush(v);
            this._a("textColor", brushToString(this.i.dy));
        }
        /**
         * Gets or sets whether the filter input is visible.
        */
        get showFilter() {
            return this.i.aq;
        }
        set showFilter(v) {
            this.i.aq = ensureBool(v);
            this._a("showFilter", this.i.aq);
        }
        /**
         * Gets or sets whether row hover highlighting is enabled.
        */
        get isRowHoverEnabled() {
            return this.i.an;
        }
        set isRowHoverEnabled(v) {
            this.i.an = ensureBool(v);
            this._a("isRowHoverEnabled", this.i.an);
        }
        findByName(name) {
            if (this.findEphemera) {
                if (name && name.indexOf("@@e:") == 0) {
                    return this.findEphemera(name);
                }
            }
            if (this.keys != null && this.keys.findByName && this.keys.findByName(name)) {
                return this.keys.findByName(name);
            }
            return null;
        }
        get hasUserValues() {
            return this._hasUserValues;
        }
        __m(propertyName) {
            if (!this._inStyling) {
                this._hasUserValues.add(propertyName);
            }
        }
        _styling(container, component, parent) {
            if (this._inStyling) {
                return;
            }
            this._inStyling = true;
            this._stylingContainer = container;
            this._stylingParent = component;
            let genericPrefix = "";
            let typeName = this.i.$type.name;
            if (typeName.indexOf("Xam") === 0) {
                typeName = typeName.substring(3);
            }
            genericPrefix = toSpinal("CheckboxListComponent");
            let additionalPrefixes = [];
            let prefix = toSpinal(typeName);
            additionalPrefixes.push(prefix + "-");
            let b = this.i.$type.baseType;
            while (b && b.name != "Object" &&
                b.name != "Base" &&
                b.name != "Control" &&
                b.Name != "DependencyObject" &&
                b.Name != "FrameworkElement") {
                typeName = b.name;
                if (typeName.indexOf("Xam") === 0) {
                    typeName = typeName.substring(3);
                }
                let basePrefix = toSpinal(typeName);
                additionalPrefixes.push(basePrefix + "-");
                b = b.baseType;
            }
            if (parent) {
                let parentTypeName = parent.i.$type.name;
                if (parentTypeName.indexOf("Xam") === 0) {
                    parentTypeName = parentTypeName.substring(3);
                }
                let parentPrefix = toSpinal(parentTypeName);
                additionalPrefixes.push(parentPrefix + "-" + genericPrefix + "-");
                additionalPrefixes.push(parentPrefix + "-" + prefix + "-");
            }
            initializePropertiesFromCss(container, this, genericPrefix + "-", this.hasUserValues, false, additionalPrefixes);
            if (this._otherStyling) {
                this._otherStyling(container, component, parent);
            }
            this._inStyling = false;
        }
        /**
     * selects all the items in the checkbox list.
    
    */
        selectAll() {
            this.i.cy();
        }
        /**
         * Deselects all the items in the checkbox list.
        
        */
        deselectAll() {
            this.i.b9();
        }
        notifySetItem(index, oldItem, newItem) {
            this.i.cg(index, oldItem, newItem);
        }
        /**
         * Manually notifies the checkboxlist's grid that the data it has bound to has been cleared and needs to be re-examined.
         * This should not be called if the data that the grid is bound to is already observable.
        
        */
        notifyClearItems() {
            this.i.cd();
        }
        notifyInsertItem(index, newItem) {
            this.i.ce(index, newItem);
        }
        notifyRemoveItem(index, oldItem) {
            this.i.cf(index, oldItem);
        }
        addKeyValue(value) {
            this.i.b6(value);
        }
        removeKeyValue(value) {
            this.i.cx(value);
        }
        /**
         * Returns true if no items are selected / checked; otherwise false.
        
        */
        isNothingSelected() {
            let iv = this.i.al();
            return (iv);
        }
        /**
         * Returns true if all of the items are selected / checked; otherwise false.
        
        */
        isEverythingSelected() {
            let iv = this.i.ak();
            return (iv);
        }
        /**
         * Called when a checkbox is checked or unchecked.
        */
        get checkedChanged() {
            return this._checkedChanged;
        }
        set checkedChanged(ev) {
            if (this._checkedChanged_wrapped !== null) {
                this.i.checkedChanged = delegateRemove(this.i.checkedChanged, this._checkedChanged_wrapped);
                this._checkedChanged_wrapped = null;
                this._checkedChanged = null;
            }
            this._checkedChanged = ev;
            this._checkedChanged_wrapped = (o, e) => {
                let outerArgs = new IgcCheckedChangedEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeCheckedChanged) {
                    this.beforeCheckedChanged(this, outerArgs);
                }
                if (this._checkedChanged) {
                    this._checkedChanged(this, outerArgs);
                }
            };
            this.i.checkedChanged = delegateCombine(this.i.checkedChanged, this._checkedChanged_wrapped);
            ;
        }
        /**
         * Called when the SelectAll checkbox is checked or unchecked.
        */
        get selectAllCheckboxChanged() {
            return this._selectAllCheckboxChanged;
        }
        set selectAllCheckboxChanged(ev) {
            if (this._selectAllCheckboxChanged_wrapped !== null) {
                this.i.selectAllCheckboxChanged = delegateRemove(this.i.selectAllCheckboxChanged, this._selectAllCheckboxChanged_wrapped);
                this._selectAllCheckboxChanged_wrapped = null;
                this._selectAllCheckboxChanged = null;
            }
            this._selectAllCheckboxChanged = ev;
            this._selectAllCheckboxChanged_wrapped = (o, e) => {
                let outerArgs = new IgcSelectAllCheckboxChangedEventArgs();
                outerArgs._provideImplementation(e);
                if (this.beforeSelectAllCheckboxChanged) {
                    this.beforeSelectAllCheckboxChanged(this, outerArgs);
                }
                if (this._selectAllCheckboxChanged) {
                    this._selectAllCheckboxChanged(this, outerArgs);
                }
            };
            this.i.selectAllCheckboxChanged = delegateCombine(this.i.selectAllCheckboxChanged, this._selectAllCheckboxChanged_wrapped);
            ;
        }
    }
    IgcCheckboxListComponent._observedAttributesIgcCheckboxListComponent = null;
    IgcCheckboxListComponent.htmlTagName = "igc-checkbox-list";
    IgcCheckboxListComponent._isElementRegistered = false;
    return IgcCheckboxListComponent;
})();
