import { DataBindingEventArgs as DataBindingEventArgs_internal } from "./DataBindingEventArgs";
import { IgcDateTimeCellInfo } from "./igc-date-time-cell-info";
import { IgcImageCellInfo } from "./igc-image-cell-info";
import { IgcNumericCellInfo } from "./igc-numeric-cell-info";
import { IgcRowSeparatorInfo } from "./igc-row-separator-info";
import { IgcSectionHeaderCellInfo } from "./igc-section-header-cell-info";
import { IgcTemplateCellInfo } from "./igc-template-cell-info";
import { IgcTemplateHeaderCellInfo } from "./igc-template-header-cell-info";
import { IgcTemplateSectionHeaderCellInfo } from "./igc-template-section-header-cell-info";
import { IgcTextCellInfo } from "./igc-text-cell-info";
import { IgcTextHeaderCellInfo } from "./igc-text-header-cell-info";
/**
 * Information about the data binding taking place.
*/
export class IgcDataBindingEventArgs {
    createImplementation() {
        return new DataBindingEventArgs_internal();
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    /**
     * The backing information for the current cell.
    */
    get cellInfo() {
        if (this.i.cellInfo == null) {
            return null;
        }
        if (!this.i.cellInfo.externalObject) {
            let ext = null;
            switch (this.i.cellInfo.$type.name) {
                case "DateTimeCellModel":
                    ext = new IgcDateTimeCellInfo();
                    break;
                case "ImageCellModel":
                    ext = new IgcImageCellInfo();
                    break;
                case "NumericCellModel":
                    ext = new IgcNumericCellInfo();
                    break;
                case "RowSeparatorModel":
                    ext = new IgcRowSeparatorInfo();
                    break;
                case "SectionHeaderCellModel":
                    ext = new IgcSectionHeaderCellInfo();
                    break;
                case "TemplateCellModel":
                    ext = new IgcTemplateCellInfo();
                    break;
                case "TemplateHeaderCellModel":
                    ext = new IgcTemplateHeaderCellInfo();
                    break;
                case "TemplateSectionHeaderCellModel":
                    ext = new IgcTemplateSectionHeaderCellInfo();
                    break;
                case "TextCellModel":
                    ext = new IgcTextCellInfo();
                    break;
                case "TextHeaderCellModel":
                    ext = new IgcTextHeaderCellInfo();
                    break;
            }
            ext._implementation = this.i.cellInfo;
            this.i.cellInfo.externalObject = ext;
        }
        return this.i.cellInfo.externalObject;
    }
    /**
 * The resolved value for the cell.
*/
    get resolvedValue() {
        return this.i.resolvedValue;
    }
    set resolvedValue(v) {
        this.i.resolvedValue = v;
    }
    /**
     * The data for the row in which the cell is contained.
    */
    get rowObject() {
        return this.i.rowObject;
    }
    set rowObject(v) {
        this.i.rowObject = v;
    }
}
