import { delegateCombine, delegateRemove } from "igniteui-webcomponents-core";
import { IgcGridColumnAnimationSettings } from "./igc-grid-column-animation-settings";
import { IgcColumnWidth } from "./igc-column-width";
import { IgcHeaderComponent } from "./igc-header-component";
import { ColumnSortDirection_$type } from "./ColumnSortDirection";
import { PinnedPositions_$type } from "./PinnedPositions";
import { ColumnOptionsIconAlignment_$type } from "./ColumnOptionsIconAlignment";
import { ColumnOptionsIconBehavior_$type } from "./ColumnOptionsIconBehavior";
import { MergedCellMode_$type } from "./MergedCellMode";
import { MergedCellEvaluationCriteria_$type } from "./MergedCellEvaluationCriteria";
import { CellContentVerticalAlignment_$type } from "./CellContentVerticalAlignment";
import { FilterComparisonType_$type } from "./FilterComparisonType";
import { IgcGridFilterOperandsCollection } from "./igc-grid-filter-operands-collection";
import { IgcDefinitionBaseComponent } from "./igc-definition-base-component";
import { getAllPropertyNames, toSpinal, brushToString, stringToBrush, ensureBool, ensureEnum, enumToString } from "igniteui-webcomponents-core";
import { ColumnWidth as ColumnWidth_internal } from "./ColumnWidth";
import { FontInfo } from "igniteui-webcomponents-core";
import { GridFilterOperandsCollection as GridFilterOperandsCollection_internal } from "./GridFilterOperandsCollection";
import { FilterOperand } from "./FilterOperand";
import { SyncableObservableCollection$1 } from "igniteui-webcomponents-core";
/**
 * A column in the data grid.
*/
export let IgcDataGridColumnComponent = /*@__PURE__*/ (() => {
    class IgcDataGridColumnComponent extends IgcDefinitionBaseComponent {
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
            this._filterOperands = null;
            this._actualHeaderTextChange = null;
            this._actualHeaderTextChange_wrapped = null;
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcDataGridColumnComponent._observedAttributesIgcDataGridColumnComponent == null) {
                let names = getAllPropertyNames(IgcDataGridColumnComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcDataGridColumnComponent._observedAttributesIgcDataGridColumnComponent = names;
            }
            return IgcDataGridColumnComponent._observedAttributesIgcDataGridColumnComponent;
        }
        /**
         * Gets or sets the amount of left padding to use for the cell content for this column.
        */
        get paddingLeft() {
            return this.i.h2;
        }
        set paddingLeft(v) {
            this.i.h2 = +v;
            this._a("paddingLeft", this.i.h2);
        }
        /**
         * Gets or sets the amount of top padding to use for the cell content for this column.
        */
        get paddingTop() {
            return this.i.h4;
        }
        set paddingTop(v) {
            this.i.h4 = +v;
            this._a("paddingTop", this.i.h4);
        }
        /**
         * Gets or sets the amount of right padding to use for the cell content of this column.
        */
        get paddingRight() {
            return this.i.h3;
        }
        set paddingRight(v) {
            this.i.h3 = +v;
            this._a("paddingRight", this.i.h3);
        }
        /**
         * Gets or sets the amount of bottom padding to use for the cell content of this column.
        */
        get paddingBottom() {
            return this.i.h1;
        }
        set paddingBottom(v) {
            this.i.h1 = +v;
            this._a("paddingBottom", this.i.h1);
        }
        /**
         * Gets or sets an unique name of the Column
        */
        get name() {
            return this.i.jz;
        }
        set name(v) {
            this.i.jz = v;
        }
        /**
         * Gets or sets the key used for the column binding
        */
        get field() {
            return this.i.i8;
        }
        set field(v) {
            this.i.i8 = v;
        }
        /**
         * Gets or sets the text displayed in the header of the column
        */
        get headerText() {
            return this.i.jf;
        }
        set headerText(v) {
            this.i.jf = v;
        }
        /**
         * Gets the actual text displayed in the header of the column
        */
        get actualHeaderText() {
            return this.i.im;
        }
        set actualHeaderText(v) {
            this.i.im = v;
        }
        /**
         * Gets or sets the background color to use for the cells when they are selected
        */
        get selectedBackground() {
            return brushToString(this.i.lk);
        }
        set selectedBackground(v) {
            this.i.lk = stringToBrush(v);
            this._a("selectedBackground", brushToString(this.i.lk));
        }
        /**
         * Gets the actual background color that is used for the cells when they are selected
        */
        get actualSelectedBackground() {
            return brushToString(this.i.ld);
        }
        set actualSelectedBackground(v) {
            this.i.ld = stringToBrush(v);
            this._a("actualSelectedBackground", brushToString(this.i.ld));
        }
        /**
         * Gets or sets the background color to use for the cells when the row is hovered.
        */
        get rowHoverBackground() {
            return brushToString(this.i.li);
        }
        set rowHoverBackground(v) {
            this.i.li = stringToBrush(v);
            this._a("rowHoverBackground", brushToString(this.i.li));
        }
        /**
         * Gets the actual background color that is used for the cells when they are hovered.
        */
        get actualHoverBackground() {
            return brushToString(this.i.lb);
        }
        set actualHoverBackground(v) {
            this.i.lb = stringToBrush(v);
            this._a("actualHoverBackground", brushToString(this.i.lb));
        }
        /**
         * Gets or sets the text color to use for the cells when the row is hovered.
        */
        get rowHoverTextColor() {
            return brushToString(this.i.lj);
        }
        set rowHoverTextColor(v) {
            this.i.lj = stringToBrush(v);
            this._a("rowHoverTextColor", brushToString(this.i.lj));
        }
        /**
         * Gets the actual text color that is used for the cells when they are hovered.
        */
        get actualRowHoverTextColor() {
            return brushToString(this.i.lc);
        }
        set actualRowHoverTextColor(v) {
            this.i.lc = stringToBrush(v);
            this._a("actualRowHoverTextColor", brushToString(this.i.lc));
        }
        /**
         * Gets or sets the animation settings to use for this column.
        */
        get animationSettings() {
            const r = this.i.fs;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = new IgcGridColumnAnimationSettings();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        set animationSettings(v) {
            v == null ? this.i.fs = null : this.i.fs = v.i;
        }
        /**
         * Gets or sets the width to use for this column.
        */
        get width() {
            const r = this.i.width;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = new IgcColumnWidth();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        set width(v) {
            if (typeof v == "string") {
                let int = ColumnWidth_internal.parse(v);
                let ext = new IgcColumnWidth();
                ext._implementation = int;
                v = ext;
            }
            v == null ? this.i.width = null : this.i.width = v.i;
        }
        /**
         * Gets or sets the minimum width to use for this column. Overrides the DefaultColumnMinWidth from the grid, if set.
        */
        get minWidth() {
            return this.i.hi;
        }
        set minWidth(v) {
            this.i.hi = +v;
            this._a("minWidth", this.i.hi);
        }
        /**
         * Gets whether this column was projected from markup/templates and is constrained.
        */
        get isFromMarkup() {
            return this.i.g6;
        }
        set isFromMarkup(v) {
            this.i.g6 = ensureBool(v);
            this._a("isFromMarkup", this.i.g6);
        }
        /**
         * Gets whether this column was auto generated.
        */
        get isAutoGenerated() {
            return this.i.g0;
        }
        set isAutoGenerated(v) {
            this.i.g0 = ensureBool(v);
            this._a("isAutoGenerated", this.i.g0);
        }
        /**
         * Gets or sets a filter to apply on the values of this column
        */
        get filter() {
            return this.i.ep;
        }
        set filter(v) {
            this.i.ep = v;
        }
        /**
         * Gets or sets a filter to apply to the values of this column.
        */
        get filterExpression() {
            return this.i.er;
        }
        set filterExpression(v) {
            this.i.er = v;
        }
        /**
         * Gets or sets the header definition for this column.
        */
        get header() {
            const r = this.i.header;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                let e = IgcHeaderComponent._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        }
        set header(v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.header = null : this.i.header = v.i;
        }
        /**
         * Gets or sets whether filtering is enabled for this column.
        */
        get isFilteringEnabled() {
            return this.i.g5;
        }
        set isFilteringEnabled(v) {
            this.i.g5 = ensureBool(v);
            this._a("isFilteringEnabled", this.i.g5);
        }
        /**
         * Gets or sets whether resizing is enabled for this column.
        */
        get isResizingEnabled() {
            return this.i.g8;
        }
        set isResizingEnabled(v) {
            this.i.g8 = ensureBool(v);
            this._a("isResizingEnabled", this.i.g8);
        }
        /**
         * Gets or sets whether or not a column is hidden from the grid
        */
        get isHidden() {
            return this.i.g7;
        }
        set isHidden(v) {
            this.i.g7 = ensureBool(v);
            this._a("isHidden", this.i.g7);
        }
        /**
         * Gets or sets if a column should be removed from the grid when it is fully hidden
        */
        get shouldRemoveWhenHidden() {
            return this.i.hb;
        }
        set shouldRemoveWhenHidden(v) {
            this.i.hb = ensureBool(v);
            this._a("shouldRemoveWhenHidden", this.i.hb);
        }
        /**
         * Gets the current sort direction (None, Ascending, Descending) for this column.
        */
        get sortDirection() {
            return this.i.ff;
        }
        set sortDirection(v) {
            this.i.ff = ensureEnum(ColumnSortDirection_$type, v);
            this._a("sortDirection", enumToString(ColumnSortDirection_$type, this.i.ff));
        }
        /**
         * Gets or sets the current fixed position for this column.
        */
        get pinned() {
            return this.i.f6;
        }
        set pinned(v) {
            this.i.f6 = ensureEnum(PinnedPositions_$type, v);
            this._a("pinned", enumToString(PinnedPositions_$type, this.i.f6));
        }
        /**
         * Gets the actual column options icon alignment for this column.
        */
        get actualColumnOptionsIconAlignment() {
            return this.i.e6;
        }
        set actualColumnOptionsIconAlignment(v) {
            this.i.e6 = ensureEnum(ColumnOptionsIconAlignment_$type, v);
            this._a("actualColumnOptionsIconAlignment", enumToString(ColumnOptionsIconAlignment_$type, this.i.e6));
        }
        /**
         * Gets or sets whether the column options icon is aligned opposite the header text or not.
        */
        get columnOptionsIconAlignment() {
            return this.i.e7;
        }
        set columnOptionsIconAlignment(v) {
            this.i.e7 = ensureEnum(ColumnOptionsIconAlignment_$type, v);
            this._a("columnOptionsIconAlignment", enumToString(ColumnOptionsIconAlignment_$type, this.i.e7));
        }
        /**
         * Gets the actual column options icon color for this column.
        */
        get actualColumnOptionsIconColor() {
            return brushToString(this.i.k9);
        }
        set actualColumnOptionsIconColor(v) {
            this.i.k9 = stringToBrush(v);
            this._a("actualColumnOptionsIconColor", brushToString(this.i.k9));
        }
        /**
         * Gets or sets the column options icon color for this column.
        */
        get columnOptionsIconColor() {
            return brushToString(this.i.le);
        }
        set columnOptionsIconColor(v) {
            this.i.le = stringToBrush(v);
            this._a("columnOptionsIconColor", brushToString(this.i.le));
        }
        /**
         * Gets or sets how the column option icon will behave in the column header.
        */
        get columnOptionsIconBehavior() {
            return this.i.fb;
        }
        set columnOptionsIconBehavior(v) {
            this.i.fb = ensureEnum(ColumnOptionsIconBehavior_$type, v);
            this._a("columnOptionsIconBehavior", enumToString(ColumnOptionsIconBehavior_$type, this.i.fb));
        }
        /**
         * Gets or sets how the column option icon will behave in the column header.
        */
        get actualColumnOptionsIconBehavior() {
            return this.i.fa;
        }
        set actualColumnOptionsIconBehavior(v) {
            this.i.fa = ensureEnum(ColumnOptionsIconBehavior_$type, v);
            this._a("actualColumnOptionsIconBehavior", enumToString(ColumnOptionsIconBehavior_$type, this.i.fa));
        }
        /**
         * Gets the actual state of the column options for this column.
        */
        get actualIsColumnOptionsEnabled() {
            return this.i.gt;
        }
        set actualIsColumnOptionsEnabled(v) {
            this.i.gt = ensureBool(v);
            this._a("actualIsColumnOptionsEnabled", this.i.gt);
        }
        /**
         * Gets or sets the preferred state of the column options for this column. If the feature is disabled at the grid level
         * then it will be disabled for the column regardless of what this is set to.
        */
        get isColumnOptionsEnabled() {
            return this.i.g1;
        }
        set isColumnOptionsEnabled(v) {
            this.i.g1 = ensureBool(v);
            this._a("isColumnOptionsEnabled", this.i.g1);
        }
        /**
         * Gets the actual state of summaries menu in the column options for this column.
        */
        get actualIsColumnOptionsSummariesEnabled() {
            return this.i.gv;
        }
        set actualIsColumnOptionsSummariesEnabled(v) {
            this.i.gv = ensureBool(v);
            this._a("actualIsColumnOptionsSummariesEnabled", this.i.gv);
        }
        /**
         * Gets or sets whether to show the summaries option in the column options menu for this column.
        */
        get isColumnOptionsSummariesEnabled() {
            return this.i.g3;
        }
        set isColumnOptionsSummariesEnabled(v) {
            this.i.g3 = ensureBool(v);
            this._a("isColumnOptionsSummariesEnabled", this.i.g3);
        }
        /**
         * Gets the actual state of grouping menu in the column options for this column.
        */
        get actualIsColumnOptionsGroupingEnabled() {
            return this.i.gu;
        }
        set actualIsColumnOptionsGroupingEnabled(v) {
            this.i.gu = ensureBool(v);
            this._a("actualIsColumnOptionsGroupingEnabled", this.i.gu);
        }
        /**
         * Gets or sets whether to show the grouping option in the column options menu for this column.
        */
        get isColumnOptionsGroupingEnabled() {
            return this.i.g2;
        }
        set isColumnOptionsGroupingEnabled(v) {
            this.i.g2 = ensureBool(v);
            this._a("isColumnOptionsGroupingEnabled", this.i.g2);
        }
        /**
         * Gets or sets if the column is editable.
        */
        get isEditable() {
            return this.i.g4;
        }
        set isEditable(v) {
            this.i.g4 = ensureBool(v);
            this._a("isEditable", this.i.g4);
        }
        /**
         * Gets or sets the text color used for deleted rows.
        */
        get deletedTextColor() {
            return brushToString(this.i.lf);
        }
        set deletedTextColor(v) {
            this.i.lf = stringToBrush(v);
            this._a("deletedTextColor", brushToString(this.i.lf));
        }
        /**
         * Gets the actual text color used for deleted rows.
        */
        get actualDeletedTextColor() {
            return brushToString(this.i.la);
        }
        set actualDeletedTextColor(v) {
            this.i.la = stringToBrush(v);
            this._a("actualDeletedTextColor", brushToString(this.i.la));
        }
        /**
         * Gets or sets the opacity to use for unsaved edited cell values.
        */
        get editOpacity() {
            return this.i.hh;
        }
        set editOpacity(v) {
            this.i.hh = +v;
            this._a("editOpacity", this.i.hh);
        }
        /**
         * Gets the actual opacity for unsaved edited cell values.
        */
        get actualEditOpacity() {
            return this.i.hg;
        }
        set actualEditOpacity(v) {
            this.i.hg = +v;
            this._a("actualEditOpacity", this.i.hg);
        }
        /**
         * Gets or sets the font style to use for unsaved cell edits.
        */
        get textEditStyle() {
            if (this.i.textEditStyle == null) {
                return null;
            }
            return this.i.textEditStyle.fontString;
        }
        set textEditStyle(v) {
            let fi = new FontInfo();
            fi.fontString = v;
            this.i.textEditStyle = fi;
            this._a("textEditStyle", this.i.textEditStyle != null ? this.i.textEditStyle.fontString : "");
        }
        /**
         * Gets the actual font style used for unsaved cell edits.
        */
        get actualEditFontInfo() {
            if (this.i.gb == null) {
                return null;
            }
            return this.i.gb.fontString;
        }
        set actualEditFontInfo(v) {
            let fi = new FontInfo();
            fi.fontString = v;
            this.i.gb = fi;
            this._a("actualEditFontInfo", this.i.gb != null ? this.i.gb.fontString : "");
        }
        /**
         * Gets or sets if and how cell merging is performed for this field.
        */
        get mergedCellMode() {
            return this.i.f2;
        }
        set mergedCellMode(v) {
            this.i.f2 = ensureEnum(MergedCellMode_$type, v);
            this._a("mergedCellMode", enumToString(MergedCellMode_$type, this.i.f2));
        }
        /**
         * Gets or sets how cells are evaluated for merging.
        */
        get mergedCellEvaluationCriteria() {
            return this.i.fz;
        }
        set mergedCellEvaluationCriteria(v) {
            this.i.fz = ensureEnum(MergedCellEvaluationCriteria_$type, v);
            this._a("mergedCellEvaluationCriteria", enumToString(MergedCellEvaluationCriteria_$type, this.i.fz));
        }
        /**
         * Gets or sets the vertical alignment to use for the merged cell content.
        */
        get mergedCellVerticalAlignment() {
            return this.i.ey;
        }
        set mergedCellVerticalAlignment(v) {
            this.i.ey = ensureEnum(CellContentVerticalAlignment_$type, v);
            this._a("mergedCellVerticalAlignment", enumToString(CellContentVerticalAlignment_$type, this.i.ey));
        }
        /**
         * Gets or sets the amount of left padding to use for the cell content for this column.
        */
        get mergedCellPaddingLeft() {
            return this.i.hv;
        }
        set mergedCellPaddingLeft(v) {
            this.i.hv = +v;
            this._a("mergedCellPaddingLeft", this.i.hv);
        }
        /**
         * Gets or sets the amount of top padding to use for the cell content for this column.
        */
        get mergedCellPaddingTop() {
            return this.i.hx;
        }
        set mergedCellPaddingTop(v) {
            this.i.hx = +v;
            this._a("mergedCellPaddingTop", this.i.hx);
        }
        /**
         * Gets or sets the amount of right padding to use for the cell content of this column.
        */
        get mergedCellPaddingRight() {
            return this.i.hw;
        }
        set mergedCellPaddingRight(v) {
            this.i.hw = +v;
            this._a("mergedCellPaddingRight", this.i.hw);
        }
        /**
         * Gets or sets the amount of bottom padding to use for the cell content of this column.
        */
        get mergedCellPaddingBottom() {
            return this.i.hu;
        }
        set mergedCellPaddingBottom(v) {
            this.i.hu = +v;
            this._a("mergedCellPaddingBottom", this.i.hu);
        }
        /**
         * Gets or sets whether UI filters are case sensitive or not.
        */
        get filterComparisonType() {
            return this.i.fn;
        }
        set filterComparisonType(v) {
            this.i.fn = ensureEnum(FilterComparisonType_$type, v);
            this._a("filterComparisonType", enumToString(FilterComparisonType_$type, this.i.fn));
        }
        /**
         * Gets a list of the current custom filters for this column.
        */
        get filterOperands() {
            if (this._filterOperands === null) {
                let coll = new IgcGridFilterOperandsCollection();
                let innerColl = this.i.fu;
                if (!innerColl) {
                    innerColl = new GridFilterOperandsCollection_internal();
                }
                this._filterOperands = coll._fromInner(innerColl);
            }
            return this._filterOperands;
        }
        set filterOperands(v) {
            if (this._filterOperands !== null) {
                this._filterOperands._setSyncTarget(null);
                this._filterOperands = null;
            }
            let coll = new IgcGridFilterOperandsCollection();
            this._filterOperands = coll._fromOuter(v);
            let syncColl = new SyncableObservableCollection$1(FilterOperand.$type);
            let innerColl = this.i.fu;
            if (!innerColl) {
                innerColl = new GridFilterOperandsCollection_internal();
            }
            syncColl._inner = innerColl;
            syncColl.clear();
            this._filterOperands._setSyncTarget(syncColl);
        }
        findByName(name) {
            var baseResult = super.findByName(name);
            if (baseResult) {
                return baseResult;
            }
            if (this.animationSettings && this.animationSettings.name && this.animationSettings.name == name) {
                return this.animationSettings;
            }
            if (this.width && this.width.name && this.width.name == name) {
                return this.width;
            }
            if (this.header && this.header.name && this.header.name == name) {
                return this.header;
            }
            if (this.filterOperands != null && this.filterOperands.findByName && this.filterOperands.findByName(name)) {
                return this.filterOperands.findByName(name);
            }
            return null;
        }
        _styling(container, component, parent) {
            super._styling(container, component, parent);
            this._inStyling = true;
            if (this.header && this.header._styling) {
                this.header._styling(container, component, this);
            }
            this._inStyling = false;
        }
        /**
         * Get the unique key used to identify this column.
        
        */
        getUniqueKey() {
            let iv = this.i.jd();
            return (iv);
        }
        setNamedHeaderValue(valueName, animationType, value) {
            this.i.kk(valueName, (animationType == null ? null : animationType), value);
        }
        /**
         * Returns if the column has named header values.
        
        */
        hasNamedHeaderValues() {
            let iv = this.i.gy();
            return (iv);
        }
        /**
         * Returns if there is a named header value with a given name.
        
        * @param valueName  * The named value to check for.
        */
        hasNamedHeaderValue(valueName) {
            let iv = this.i.gx(valueName);
            return (iv);
        }
        /**
         * Removes a named header value with the given name from the named header values for this column.
        
        * @param valueName  * The named header value to remove.
        */
        removeNamedHeaderValue(valueName) {
            this.i.kj(valueName);
        }
        /**
         * Gets the value of a named header value for this column by name.
        
        * @param valueName  * Name of the named header value to retrieve.
        */
        getNamedHeaderValue(valueName) {
            let iv = this.i.h9(valueName);
            return (iv);
        }
        applyCustomFilter(filterID, index, value) {
            this.i.ke(filterID, index, value);
        }
        get actualHeaderTextChange() {
            return this._actualHeaderTextChange;
        }
        set actualHeaderTextChange(ev) {
            if (this._actualHeaderTextChange_wrapped !== null) {
                this.i.propertyChanged = delegateRemove(this.i.propertyChanged, this._actualHeaderTextChange_wrapped);
                this._actualHeaderTextChange_wrapped = null;
                this._actualHeaderTextChange = null;
            }
            this._actualHeaderTextChange = ev;
            this._actualHeaderTextChange_wrapped = (o, e) => {
                let ext = this.actualHeaderText;
                if (e.propertyName == 'Im') {
                    if (this.beforeActualHeaderTextChange) {
                        this.beforeActualHeaderTextChange(this, ext);
                    }
                    if (this._actualHeaderTextChange) {
                        this._actualHeaderTextChange(this, ext);
                    }
                }
            };
            this.i.propertyChanged = delegateCombine(this.i.propertyChanged, this._actualHeaderTextChange_wrapped);
        }
    }
    IgcDataGridColumnComponent._observedAttributesIgcDataGridColumnComponent = null;
    return IgcDataGridColumnComponent;
})();
