import { SortIndicatorStyle_$type } from "./SortIndicatorStyle";
import { IgcDefinitionBaseComponent } from "./igc-definition-base-component";
import { getAllPropertyNames, toSpinal, brushToString, stringToBrush, ensureEnum, enumToString } from "igniteui-webcomponents-core";
/**
 * Represents a base class used to configure the appearance of the column header cells.
*/
export let IgcHeaderComponent = /*@__PURE__*/ (() => {
    class IgcHeaderComponent extends IgcDefinitionBaseComponent {
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcHeaderComponent._observedAttributesIgcHeaderComponent == null) {
                let names = getAllPropertyNames(IgcHeaderComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcHeaderComponent._observedAttributesIgcHeaderComponent = names;
            }
            return IgcHeaderComponent._observedAttributesIgcHeaderComponent;
        }
        /**
         * Gets or sets the color to use for the sort indicator icon
        */
        get sortIndicatorColor() {
            return brushToString(this.i.fc);
        }
        set sortIndicatorColor(v) {
            this.i.fc = stringToBrush(v);
            this._a("sortIndicatorColor", brushToString(this.i.fc));
        }
        /**
         * Gets the actual background color that is used for the cells when they are selected
        */
        get actualSortIndicatorColor() {
            return brushToString(this.i.fa);
        }
        set actualSortIndicatorColor(v) {
            this.i.fa = stringToBrush(v);
            this._a("actualSortIndicatorColor", brushToString(this.i.fa));
        }
        get sortIndicatorStyle() {
            return this.i.ep;
        }
        set sortIndicatorStyle(v) {
            this.i.ep = ensureEnum(SortIndicatorStyle_$type, v);
            this._a("sortIndicatorStyle", enumToString(SortIndicatorStyle_$type, this.i.ep));
        }
        get actualSortIndicatorStyle() {
            return this.i.eo;
        }
        set actualSortIndicatorStyle(v) {
            this.i.eo = ensureEnum(SortIndicatorStyle_$type, v);
            this._a("actualSortIndicatorStyle", enumToString(SortIndicatorStyle_$type, this.i.eo));
        }
        /**
         * Gets or sets the amount of left padding to use for the cell content.
        */
        get paddingLeft() {
            return this.i.ev;
        }
        set paddingLeft(v) {
            this.i.ev = +v;
            this._a("paddingLeft", this.i.ev);
        }
        /**
         * Gets or sets the amount of top padding to use for the cell content.
        */
        get paddingTop() {
            return this.i.ex;
        }
        set paddingTop(v) {
            this.i.ex = +v;
            this._a("paddingTop", this.i.ex);
        }
        /**
         * Gets or sets the amount of right padding to use for the cell content.
        */
        get paddingRight() {
            return this.i.ew;
        }
        set paddingRight(v) {
            this.i.ew = +v;
            this._a("paddingRight", this.i.ew);
        }
        /**
         * Gets or sets the amount of bottom padding to use for the cell content.
        */
        get paddingBottom() {
            return this.i.eu;
        }
        set paddingBottom(v) {
            this.i.eu = +v;
            this._a("paddingBottom", this.i.eu);
        }
    }
    IgcHeaderComponent._observedAttributesIgcHeaderComponent = null;
    return IgcHeaderComponent;
})();
