import { ImageStretchOptions_$type } from "./ImageStretchOptions";
import { EditorType_$type } from "./EditorType";
import { IgcDataGridColumnComponent } from "./igc-data-grid-column-component";
import { ImageColumn } from "./ImageColumn";
import { getAllPropertyNames, toSpinal, ensureEnum, enumToString } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Represents an Image grid column, used to allow the developer to display an image in a cell.
*/
export let IgcImageColumnComponent = /*@__PURE__*/ (() => {
    class IgcImageColumnComponent extends IgcDataGridColumnComponent {
        createImplementation() {
            return new ImageColumn();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcImageColumnComponent._observedAttributesIgcImageColumnComponent == null) {
                let names = getAllPropertyNames(IgcImageColumnComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcImageColumnComponent._observedAttributesIgcImageColumnComponent = names;
            }
            return IgcImageColumnComponent._observedAttributesIgcImageColumnComponent;
        }
        static register() {
            if (!IgcImageColumnComponent._isElementRegistered) {
                IgcImageColumnComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcImageColumnComponent.htmlTagName, IgcImageColumnComponent);
            }
        }
        /**
         * Gets or sets the stretch option to use when rendering images
        */
        get imageStretchOption() {
            return this.i.lp;
        }
        set imageStretchOption(v) {
            this.i.lp = ensureEnum(ImageStretchOptions_$type, v);
            this._a("imageStretchOption", enumToString(ImageStretchOptions_$type, this.i.lp));
        }
        /**
         * Gets or sets the editor type used for editing cells in this column.
        */
        get editorType() {
            return this.i.ll;
        }
        set editorType(v) {
            this.i.ll = ensureEnum(EditorType_$type, v);
            this._a("editorType", enumToString(EditorType_$type, this.i.ll));
        }
        /**
         * Gets or sets the ComboBox data source.
        */
        get editorDataSource() {
            return this.i.lq;
        }
        set editorDataSource(v) {
            this.i.lq = v;
        }
        /**
         * Gets or sets the ComboBox text field.
        */
        get editorTextField() {
            return this.i.lr;
        }
        set editorTextField(v) {
            this.i.lr = v;
        }
        /**
         * Gets or sets the ComboBox value field.
        */
        get editorValueField() {
            return this.i.ls;
        }
        set editorValueField(v) {
            this.i.ls = v;
        }
    }
    IgcImageColumnComponent._observedAttributesIgcImageColumnComponent = null;
    IgcImageColumnComponent.htmlTagName = "igc-image-column";
    IgcImageColumnComponent._isElementRegistered = false;
    return IgcImageColumnComponent;
})();
