import { EditorType_$type } from "./EditorType";
import { IgcDataGridColumnComponent } from "./igc-data-grid-column-component";
import { NumericColumn } from "./NumericColumn";
import { getAllPropertyNames, toSpinal, ensureBool, ensureEnum, enumToString, arrayFindByName } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Represents a Numeric grid column, used to allow the developer to display a formatted number in a cell.
*/
export let IgcNumericColumnComponent = /*@__PURE__*/ (() => {
    class IgcNumericColumnComponent extends IgcDataGridColumnComponent {
        createImplementation() {
            return new NumericColumn();
        }
        /**
                                     * @hidden
                                     */
        get i() {
            return this._implementation;
        }
        constructor() {
            super();
        }
        connectedCallback() {
            if (super["connectedCallback"]) {
                super["connectedCallback"]();
            }
            if (this.i.connectedCallback) {
                this.i.connectedCallback();
            }
            if (!this._attached) {
                this._attached = true;
                this._flushQueuedAttributes();
            }
        }
        disconnectedCallback() {
            if (super["disconnectedCallback"]) {
                super["disconnectedCallback"]();
            }
            if (this.i.disconnectedCallback) {
                this.i.disconnectedCallback();
            }
            if (this._attached) {
                this._attached = false;
            }
        }
        static get observedAttributes() {
            if (IgcNumericColumnComponent._observedAttributesIgcNumericColumnComponent == null) {
                let names = getAllPropertyNames(IgcNumericColumnComponent);
                for (let i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcNumericColumnComponent._observedAttributesIgcNumericColumnComponent = names;
            }
            return IgcNumericColumnComponent._observedAttributesIgcNumericColumnComponent;
        }
        static register() {
            if (!IgcNumericColumnComponent._isElementRegistered) {
                IgcNumericColumnComponent._isElementRegistered = true;
                RegisterElementHelper.registerElement(IgcNumericColumnComponent.htmlTagName, IgcNumericColumnComponent);
            }
        }
        /**
         * Gets or sets the string to prefix a negative value. If FormatString is specificied this value is ignored.
        */
        get negativePrefix() {
            return this.i.mg;
        }
        set negativePrefix(v) {
            this.i.mg = v;
        }
        /**
         * Gets or sets the string to prefix a positive value. If FormatString is specificied this value is ignored.
        */
        get positivePrefix() {
            return this.i.mk;
        }
        set positivePrefix(v) {
            this.i.mk = v;
        }
        /**
         * Gets or sets the string to suffix a negative value. If FormatString is specificied this value is ignored.
        */
        get negativeSuffix() {
            return this.i.mi;
        }
        set negativeSuffix(v) {
            this.i.mi = v;
        }
        /**
         * Gets or sets the string to suffix a positive value. If FormatString is specificied this value is ignored.
        */
        get positiveSuffix() {
            return this.i.mm;
        }
        set positiveSuffix(v) {
            this.i.mm = v;
        }
        /**
         * Gets or sets the maximum fraction digits. If FormatString is specificied this value is ignored.
        */
        get maxFractionDigits() {
            return this.i.lv;
        }
        set maxFractionDigits(v) {
            this.i.lv = +v;
            this._a("maxFractionDigits", this.i.lv);
        }
        /**
         * Gets or sets the minimum fraction digits. If FormatString is specificied this value is ignored.
        */
        get minFractionDigits() {
            return this.i.lw;
        }
        set minFractionDigits(v) {
            this.i.lw = +v;
            this._a("minFractionDigits", this.i.lw);
        }
        /**
         * Gets or sets the minimum integer digits. If FormatString is specificied this value is ignored.
        */
        get minIntegerDigits() {
            return this.i.lx;
        }
        set minIntegerDigits(v) {
            this.i.lx = +v;
            this._a("minIntegerDigits", this.i.lx);
        }
        /**
         * Gets or sets whether to show a grouping separator. If FormatString is specificied this value is ignored.
        */
        get showGroupingSeparator() {
            return this.i.lq;
        }
        set showGroupingSeparator(v) {
            this.i.lq = ensureBool(v);
            this._a("showGroupingSeparator", this.i.lq);
        }
        /**
         * Gets or sets the format string to apply to the value. If set, the other value formatting properties on this column are ignored.
        */
        get formatString() {
            return this.i.mb;
        }
        set formatString(v) {
            this.i.mb = v;
        }
        get formatSpecifiers() {
            return this.i.lm;
        }
        set formatSpecifiers(v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                const re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.lm = v;
        }
        /**
         * Gets or sets the INTL NumericFormat object to use for formatting the date values.
        */
        get formatOverride() {
            return this.i.l0;
        }
        set formatOverride(v) {
            this.i.l0 = v;
        }
        /**
         * Gets or sets the editor type used for editing cells in this column.
        */
        get editorType() {
            return this.i.lo;
        }
        set editorType(v) {
            this.i.lo = ensureEnum(EditorType_$type, v);
            this._a("editorType", enumToString(EditorType_$type, this.i.lo));
        }
        /**
         * Gets or sets the ComboBox data source.
        */
        get editorDataSource() {
            return this.i.lz;
        }
        set editorDataSource(v) {
            this.i.lz = v;
        }
        /**
         * Gets or sets the ComboBox text field.
        */
        get editorTextField() {
            return this.i.l6;
        }
        set editorTextField(v) {
            this.i.l6 = v;
        }
        /**
         * Gets or sets the ComboBox value field.
        */
        get editorValueField() {
            return this.i.l7;
        }
        set editorValueField(v) {
            this.i.l7 = v;
        }
        findByName(name) {
            var baseResult = super.findByName(name);
            if (baseResult) {
                return baseResult;
            }
            if (this.formatSpecifiers != null && arrayFindByName(this.formatSpecifiers, name)) {
                return arrayFindByName(this.formatSpecifiers, name);
            }
            return null;
        }
    }
    IgcNumericColumnComponent._observedAttributesIgcNumericColumnComponent = null;
    IgcNumericColumnComponent.htmlTagName = "igc-numeric-column";
    IgcNumericColumnComponent._isElementRegistered = false;
    return IgcNumericColumnComponent;
})();
