import { TemplateHeaderCellUpdatingEventArgs as TemplateHeaderCellUpdatingEventArgs_internal } from "./TemplateHeaderCellUpdatingEventArgs";
import { IgcDateTimeCellInfo } from "./igc-date-time-cell-info";
import { IgcImageCellInfo } from "./igc-image-cell-info";
import { IgcNumericCellInfo } from "./igc-numeric-cell-info";
import { IgcRowSeparatorInfo } from "./igc-row-separator-info";
import { IgcSectionHeaderCellInfo } from "./igc-section-header-cell-info";
import { IgcTemplateCellInfo } from "./igc-template-cell-info";
import { IgcTemplateHeaderCellInfo } from "./igc-template-header-cell-info";
import { IgcTemplateSectionHeaderCellInfo } from "./igc-template-section-header-cell-info";
import { IgcTextCellInfo } from "./igc-text-cell-info";
import { IgcTextHeaderCellInfo } from "./igc-text-header-cell-info";
/**
 * Information about the header cell that has content which is being created or updated.
*/
export class IgcTemplateHeaderCellUpdatingEventArgs {
    createImplementation() {
        return new TemplateHeaderCellUpdatingEventArgs_internal();
    }
    get i() {
        return this._implementation;
    }
    onImplementationCreated() {
    }
    constructor() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    _provideImplementation(i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    get isCanvasBased() {
        return this.i.content.isCanvasBased;
    }
    /**
     * The host in which to add or update content if this is a DOM based cell.
    */
    get content() {
        if (this.isCanvasBased) {
            return null;
        }
        else {
            return this.i.content.element.getNativeElement();
        }
    }
    get context() {
        if (this.isCanvasBased) {
            return this.i.content.templateContext;
        }
        else {
            return null;
        }
    }
    ensureCorrectSize() {
        return this.i.content.ensureCorrectSize();
    }
    renderStandardBackground() {
        this.i.content.renderStandardBackground();
    }
    renderStandardContent() {
        this.i.content.renderStandardContent();
    }
    /**
     * The backing information for the current cell.
    */
    get cellInfo() {
        if (this.i.cellInfo == null) {
            return null;
        }
        if (!this.i.cellInfo.externalObject) {
            let ext = null;
            switch (this.i.cellInfo.$type.name) {
                case "DateTimeCellModel":
                    ext = new IgcDateTimeCellInfo();
                    break;
                case "ImageCellModel":
                    ext = new IgcImageCellInfo();
                    break;
                case "NumericCellModel":
                    ext = new IgcNumericCellInfo();
                    break;
                case "RowSeparatorModel":
                    ext = new IgcRowSeparatorInfo();
                    break;
                case "SectionHeaderCellModel":
                    ext = new IgcSectionHeaderCellInfo();
                    break;
                case "TemplateCellModel":
                    ext = new IgcTemplateCellInfo();
                    break;
                case "TemplateHeaderCellModel":
                    ext = new IgcTemplateHeaderCellInfo();
                    break;
                case "TemplateSectionHeaderCellModel":
                    ext = new IgcTemplateSectionHeaderCellInfo();
                    break;
                case "TextCellModel":
                    ext = new IgcTextCellInfo();
                    break;
                case "TextHeaderCellModel":
                    ext = new IgcTextHeaderCellInfo();
                    break;
            }
            ext._implementation = this.i.cellInfo;
            this.i.cellInfo.externalObject = ext;
        }
        return this.i.cellInfo.externalObject;
    }
}
