import { __extends } from "tslib";
import { IgcCellInfo } from "./igc-cell-info";
import { DataSourceSchemaPropertyType_$type } from "igniteui-webcomponents-core";
import { EditorType_$type } from "./EditorType";
import { EditorCellModel as EditorCellModel_internal } from "./EditorCellModel";
import { ensureBool, ensureEnum } from "igniteui-webcomponents-core";
/**
 * Represents info about the current cell.
*/
var IgcEditorCellInfo = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcEditorCellInfo, _super);
    function IgcEditorCellInfo() {
        return _super.call(this) || this;
    }
    IgcEditorCellInfo.prototype.createImplementation = function () {
        return new EditorCellModel_internal();
    };
    Object.defineProperty(IgcEditorCellInfo.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcEditorCellInfo.prototype, "isHidden", {
        /**
         * Gets whether the editor cell is hidden or not.
        */
        get: function () {
            return this.i.lv;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcEditorCellInfo.prototype, "editTarget", {
        /**
         * Gets or sets the edit target for this cell.
        */
        get: function () {
            var r = this.i.lo;
            if (r == null) {
                return null;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.lo = null : this.i.lo = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcEditorCellInfo.prototype, "dataType", {
        /**
         * Gets or sets the data type associated with the cell being edited.
        */
        get: function () {
            return this.i.lm;
        },
        set: function (v) {
            this.i.lm = ensureEnum(DataSourceSchemaPropertyType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcEditorCellInfo.prototype, "errorMessage", {
        /**
         * Gets or sets the error message to display in the editor cell.
        */
        get: function () {
            return this.i.mr;
        },
        set: function (v) {
            this.i.mr = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcEditorCellInfo.prototype, "editValue", {
        /**
         * Gets or sets the user selected value.
        */
        get: function () {
            return this.i.me;
        },
        set: function (v) {
            this.i.me = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcEditorCellInfo.prototype, "editorType", {
        /**
         * Gets or sets the type of editor to use while cell editing.
        */
        get: function () {
            return this.i.lq;
        },
        set: function (v) {
            this.i.lq = ensureEnum(EditorType_$type, v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcEditorCellInfo.prototype, "editorDataSource", {
        /**
         * Gets or sets the data source to use for the editor where it makes sense.
        */
        get: function () {
            return this.i.md;
        },
        set: function (v) {
            this.i.md = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcEditorCellInfo.prototype, "editorTextField", {
        /**
         * Gets or sets the editors display member.
        */
        get: function () {
            return this.i.mm;
        },
        set: function (v) {
            this.i.mm = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcEditorCellInfo.prototype, "editorValueField", {
        /**
         * Gets or sets the editors value member.
        */
        get: function () {
            return this.i.lk;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.lk = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcEditorCellInfo.prototype, "dateFormatString", {
        get: function () {
            return this.i.mj;
        },
        set: function (v) {
            this.i.mj = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcEditorCellInfo.prototype, "showTodayButton", {
        get: function () {
            return this.i.lw;
        },
        set: function (v) {
            this.i.lw = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcEditorCellInfo.prototype, "targetRow", {
        /**
         * Gets the row index that the editor cell is targeting for edit.
        */
        get: function () {
            return this.i.mb;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcEditorCellInfo.prototype, "targetColumn", {
        /**
         * Gets the column index that the editor cell is targeting for edit.
        */
        get: function () {
            return this.i.ma;
        },
        enumerable: false,
        configurable: true
    });
    IgcEditorCellInfo.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.editTarget && this.editTarget.name && this.editTarget.name == name) {
            return this.editTarget;
        }
        return null;
    };
    return IgcEditorCellInfo;
}(IgcCellInfo));
export { IgcEditorCellInfo };
