import { __extends } from "tslib";
import { EditorType_$type } from "./EditorType";
import { IgcDataGridColumnComponent } from "./igc-data-grid-column-component";
import { NumericColumn } from "./NumericColumn";
import { getAllPropertyNames, toSpinal, ensureBool, ensureEnum, enumToString, arrayFindByName } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
/**
 * Represents a Numeric grid column, used to allow the developer to display a formatted number in a cell.
*/
var IgcNumericColumnComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcNumericColumnComponent, _super);
    function IgcNumericColumnComponent() {
        return _super.call(this) || this;
    }
    IgcNumericColumnComponent.prototype.createImplementation = function () {
        return new NumericColumn();
    };
    Object.defineProperty(IgcNumericColumnComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcNumericColumnComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcNumericColumnComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcNumericColumnComponent, "observedAttributes", {
        get: function () {
            if (IgcNumericColumnComponent._observedAttributesIgcNumericColumnComponent == null) {
                var names = getAllPropertyNames(IgcNumericColumnComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcNumericColumnComponent._observedAttributesIgcNumericColumnComponent = names;
            }
            return IgcNumericColumnComponent._observedAttributesIgcNumericColumnComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcNumericColumnComponent.register = function () {
        if (!IgcNumericColumnComponent._isElementRegistered) {
            IgcNumericColumnComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcNumericColumnComponent.htmlTagName, IgcNumericColumnComponent);
        }
    };
    Object.defineProperty(IgcNumericColumnComponent.prototype, "negativePrefix", {
        /**
         * Gets or sets the string to prefix a negative value. If FormatString is specificied this value is ignored.
        */
        get: function () {
            return this.i.mg;
        },
        set: function (v) {
            this.i.mg = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcNumericColumnComponent.prototype, "positivePrefix", {
        /**
         * Gets or sets the string to prefix a positive value. If FormatString is specificied this value is ignored.
        */
        get: function () {
            return this.i.mk;
        },
        set: function (v) {
            this.i.mk = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcNumericColumnComponent.prototype, "negativeSuffix", {
        /**
         * Gets or sets the string to suffix a negative value. If FormatString is specificied this value is ignored.
        */
        get: function () {
            return this.i.mi;
        },
        set: function (v) {
            this.i.mi = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcNumericColumnComponent.prototype, "positiveSuffix", {
        /**
         * Gets or sets the string to suffix a positive value. If FormatString is specificied this value is ignored.
        */
        get: function () {
            return this.i.mm;
        },
        set: function (v) {
            this.i.mm = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcNumericColumnComponent.prototype, "maxFractionDigits", {
        /**
         * Gets or sets the maximum fraction digits. If FormatString is specificied this value is ignored.
        */
        get: function () {
            return this.i.lv;
        },
        set: function (v) {
            this.i.lv = +v;
            this._a("maxFractionDigits", this.i.lv);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcNumericColumnComponent.prototype, "minFractionDigits", {
        /**
         * Gets or sets the minimum fraction digits. If FormatString is specificied this value is ignored.
        */
        get: function () {
            return this.i.lw;
        },
        set: function (v) {
            this.i.lw = +v;
            this._a("minFractionDigits", this.i.lw);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcNumericColumnComponent.prototype, "minIntegerDigits", {
        /**
         * Gets or sets the minimum integer digits. If FormatString is specificied this value is ignored.
        */
        get: function () {
            return this.i.lx;
        },
        set: function (v) {
            this.i.lx = +v;
            this._a("minIntegerDigits", this.i.lx);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcNumericColumnComponent.prototype, "showGroupingSeparator", {
        /**
         * Gets or sets whether to show a grouping separator. If FormatString is specificied this value is ignored.
        */
        get: function () {
            return this.i.lq;
        },
        set: function (v) {
            this.i.lq = ensureBool(v);
            this._a("showGroupingSeparator", this.i.lq);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcNumericColumnComponent.prototype, "formatString", {
        /**
         * Gets or sets the format string to apply to the value. If set, the other value formatting properties on this column are ignored.
        */
        get: function () {
            return this.i.mb;
        },
        set: function (v) {
            this.i.mb = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcNumericColumnComponent.prototype, "formatSpecifiers", {
        get: function () {
            return this.i.lm;
        },
        set: function (v) {
            if (v && !Array.isArray(v) && typeof (v) == "string") {
                var re = /\s*(?:,|\s|$)\s*/gm;
                v = v.split(re);
            }
            this.i.lm = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcNumericColumnComponent.prototype, "formatOverride", {
        /**
         * Gets or sets the INTL NumericFormat object to use for formatting the date values.
        */
        get: function () {
            return this.i.l0;
        },
        set: function (v) {
            this.i.l0 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcNumericColumnComponent.prototype, "editorType", {
        /**
         * Gets or sets the editor type used for editing cells in this column.
        */
        get: function () {
            return this.i.lo;
        },
        set: function (v) {
            this.i.lo = ensureEnum(EditorType_$type, v);
            this._a("editorType", enumToString(EditorType_$type, this.i.lo));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcNumericColumnComponent.prototype, "editorDataSource", {
        /**
         * Gets or sets the ComboBox data source.
        */
        get: function () {
            return this.i.lz;
        },
        set: function (v) {
            this.i.lz = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcNumericColumnComponent.prototype, "editorTextField", {
        /**
         * Gets or sets the ComboBox text field.
        */
        get: function () {
            return this.i.l6;
        },
        set: function (v) {
            this.i.l6 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcNumericColumnComponent.prototype, "editorValueField", {
        /**
         * Gets or sets the ComboBox value field.
        */
        get: function () {
            return this.i.l7;
        },
        set: function (v) {
            this.i.l7 = v;
        },
        enumerable: false,
        configurable: true
    });
    IgcNumericColumnComponent.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.formatSpecifiers != null && arrayFindByName(this.formatSpecifiers, name)) {
            return arrayFindByName(this.formatSpecifiers, name);
        }
        return null;
    };
    IgcNumericColumnComponent._observedAttributesIgcNumericColumnComponent = null;
    IgcNumericColumnComponent.htmlTagName = "igc-numeric-column";
    IgcNumericColumnComponent._isElementRegistered = false;
    return IgcNumericColumnComponent;
}(IgcDataGridColumnComponent));
export { IgcNumericColumnComponent };
