import { IgcColumnPropertySetter } from "./igc-column-property-setter";
import { ResponsivePhase as ResponsivePhase_internal } from "./ResponsivePhase";
/**
 * Describes one phase of a responsive state to apply to the grid.
*/
var IgcResponsivePhase = /** @class */ /*@__PURE__*/ (function () {
    function IgcResponsivePhase() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgcResponsivePhase.prototype.createImplementation = function () {
        return new ResponsivePhase_internal();
    };
    Object.defineProperty(IgcResponsivePhase.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcResponsivePhase.prototype.onImplementationCreated = function () {
    };
    IgcResponsivePhase.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgcResponsivePhase.prototype, "name", {
        /**
         * The name of this responsive phase
        */
        get: function () {
            return this.i.k;
        },
        set: function (v) {
            this.i.k = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcResponsivePhase.prototype, "delayMilliseconds", {
        /**
         * The amount of time to delay the responsive phase from starting, in milliseconds
        */
        get: function () {
            return this.i.i;
        },
        set: function (v) {
            this.i.i = +v;
        },
        enumerable: false,
        configurable: true
    });
    IgcResponsivePhase.prototype.findByName = function (name) {
        if (this.findEphemera) {
            if (name && name.indexOf("@@e:") == 0) {
                return this.findEphemera(name);
            }
        }
        return null;
    };
    /**
     * Adds a column property setter to the phase.
    
    * @param setter  * The setter to add.
    */
    IgcResponsivePhase.prototype.addColumnPropertySetter = function (setter) {
        var iv = this.i.g((setter == null ? null : setter.i));
        var ret = null;
        if (iv && iv.externalObject) {
            ret = iv.externalObject;
        }
        else {
            if (iv) {
                var e = new IgcResponsivePhase();
                e._implementation = iv;
                iv.externalObject = e;
                ret = e;
            }
        }
        return ret;
    };
    /**
     * Adds a column property setter to the phase, and returns it.
    
    */
    IgcResponsivePhase.prototype.columnPropertySetter = function () {
        var iv = this.i.c();
        var ret = null;
        if (iv && iv.externalObject) {
            ret = iv.externalObject;
        }
        else {
            if (iv) {
                var e = new IgcColumnPropertySetter();
                e._implementation = iv;
                iv.externalObject = e;
                ret = e;
            }
        }
        return ret;
    };
    /**
     * Adds a column exchanger the the phase.
    
    * @param exchanger  * The exchanger to add.
    */
    IgcResponsivePhase.prototype.addColumnExchanger = function (exchanger) {
        var iv = this.i.f((exchanger == null ? null : exchanger.i));
        var ret = null;
        if (iv && iv.externalObject) {
            ret = iv.externalObject;
        }
        else {
            if (iv) {
                var e = new IgcResponsivePhase();
                e._implementation = iv;
                iv.externalObject = e;
                ret = e;
            }
        }
        return ret;
    };
    /**
     * Adds a column exchanger to the phase and returns it.
    
    */
    IgcResponsivePhase.prototype.columnExchanger = function () {
        var iv = this.i.h();
        var ret = null;
        if (iv && iv.externalObject) {
            ret = iv.externalObject;
        }
        else {
            if (iv) {
                var e = new IgcResponsivePhase();
                e._implementation = iv;
                iv.externalObject = e;
                ret = e;
            }
        }
        return ret;
    };
    return IgcResponsivePhase;
}());
export { IgcResponsivePhase };
